==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "Nền tảng"

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Hostname"

, "Username"
: "Tên đăng nhập"

, "Password"
: "Mật khẩu"

, "Port"
: "Cổng"

, "Secure Connection"
: "Kết nối bảo mật"

, "None"
: "Không"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Sử dụng tài khoản hệ thống"

, "No"
: "Không"

, "Yes"
: "Có"

, "Append domain to login name"
: "Ghép domain vào tên đăng nhập"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin Password"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentication"

, "Login"
: "Đăng nhập"

, "Plain"
: "Thuần text"

, "Primary Domain"
: "Domain chính"

, "Secondary Domains (comma separated)"
: "Domain phụ (cách nhau bằng dấu phẩy)"

, "Notifications service address"
: "Địa chỉ thông báo dịch vụ"

, "Notification Username"
: "Người dùng thông báo"

, "Notification Password"
: "Mật khẩu thông báo"

, "Notifications local client (hostname or IP address)"
: "Notifications local client (hostname or IP address)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Database"

, "MySql User"
: "MySql User"

, "MySql Password"
: "MySql Password"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "User or UID"

, "Group or GID"
: "Group or GID"

, "Home Template"
: "Home Template"

, "Password Scheme"
: "Password Scheme"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "I have read the license agreement and accept it"
: "Tôi đã đọc thỏa thuận về giấy phép sử dụng và chấp nhận nó."

, "License Agreement"
: "Thỏa thuận giấy phép sử dụng"

, "I have read the privacy agreement and accept it"
: "Tôi đã đọc chính sách riêng tư và chấp nhận nó"

, "Privacy Agreement"
: "Thỏa thuận chính sách"

, "Accept Terms and Conditions"
: "Điều khoản sử dụng"

, "Performing Environment Checks..."
: "Đang thực hiện kiểm tra môi trường ..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Không có gì được tìm thấy {0}. Xin thay đổi điều kiện tìm kiếm của bạn, tùy chọn xem hoặc {1} bạn tìm kiếm trong đó."

, "Check"
: "Kiểm tra"

, "Result"
: "Kết quả"

, "Error"
: "Lỗi"

, "Run setup tests"
: "Chạy kiếm tra cài đặt"

, "Ignore setup tests"
: "Bỏ qua kiểm tra cài đặt"

, "Install application"
: "Cài đặt ứng dụng"

, "File"
: "File"

, "Setup Authentication"
: "Cài đặt xác thực"

, "Database"
: "Cơ sở dữ liệu"

, "User"
: "Người dùng"

, "Prefix"
: "Tiền tố"

, "Logging"
: "Ghi lỗi"

, "Filename"
: "Tên file"

, "Priority"
: "Độ quan trọng"

, "Caching"
: "Đệm"

, "Lifetime (seconds)"
: "Lifetime (seconds)"

, "Path"
: "Đường dẫn"

, "Queue"
: "Hàng đợi"

, "Session"
: "Session"

, "Temporary files"
: "Temporary files"

, "Temporary Files Path"
: "Temporary Files Path"

, "Filestore directory"
: "Filestore directory"

, "Filestore Path"
: "Filestore Path"

, "Addressbook Map panel"
: "Addressbook Map panel"

, "Map panel"
: "Map panel"

, "disabled"
: "tắt"

, "enabled"
: "mở"

, "Config file is not writable"
: "File cấu hình không thể lưu lại"

, "Save config"
: "Lưu cấu hình"

, "Download config file"
: "Download file cấu hình"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Điều khỏa sử dụng"

, "Setup Checks"
: "Kiểm tra cài đặt"

, "Config Manager"
: "Quản lý cấu hình"

, "Authentication/Accounts"
: "Xác thực/ Tài khoản"

, "Email"
: "Email"

, "Application Manager"
: "Quản lý ứng dụng"

, "Delete all existing users and groups"
: "Xóa mọi người dùng và nhóm người dùng"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Chuyển từ SQL sang LDAP sẽ xóa mọi người dùng, nhóm, và vai trò hiện tại. Bạn có thật sự muốn chuyển chế độ lưu trữ tài khoản sang LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Người Quản trị chính"

, "Initial admin login name"
: "Tên đăng nhập Quản trị chính"

, "Initial admin Password"
: "Mật khẩu Quản trị chính"

, "Password confirmation"
: "Xác nhận mật khẩu"

, "Authentication provider"
: "Nguồn xác thực"

, "Try to split username"
: "Thử tách tên đăng nhập"

, "Account canonical form"
: "Form đăng nhập duy nhất"

, "Account domain name"
: ""

, "Account domain short name"
: "Tên ngắn của domain"

, "Host"
: "Host"

, "Login name"
: "Tên đăng nhập"

, "Bind requires DN"
: "Bind requires DN"

, "Start TLS"
: ""

, "Base DN"
: "Base DN"

, "Search filter"
: "Bộ lọc tìm kiếm"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Lưu trữ tài khoản"

, "Default user group name"
: "Tên nhóm nguwowfi dùng mặc định"

, "Default admin group name"
: "Tên nhóm quản trị mặc định"

, "Login panel"
: "Màn hình đăng nhập"

, "Reuse last username logged"
: ""

, "Password Settings"
: "Thiết lập mật khẩu"

, "User can change password"
: "Người dùng có thể đổi mật khẩu"

, "Enable password policy"
: "Bật chính sách mật khẩu"

, "Only ASCII"
: "Chỉ ASCII"

, "Minimum length"
: "Độ dài tối thiểu"

, "Minimum word chars"
: "Ký tự chữ cái tối tiểu"

, "Minimum uppercase chars"
: "Ký tự in hoa tối thiểu"

, "Minimum special chars"
: "Ký tự đặc biệt tối thiểu"

, "Minimum numbers"
: "Số tối thiểu"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Cấm sử dụng 1 phần tên đăng nhập trong mật khẩu"

, "Redirect Settings"
: "Thiết lập chuyển hướng"

, "Redirect Url (redirect to login screen if empty)"
: "URL chuyển hướng (chuyển hướng tới màn hình đăng nhập rỗng)"

, "Redirect Always (if No, only redirect after logout)"
: "Luôn chuyển hướng (Nếu không, chỉ chuyển hướng sau khi thoát)"

, "Redirect to referring site, if exists"
: "Chuyển hướng tới trang trước đó, nếu có"

, "Password encoding"
: "Mã hóa mật khaaru"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "User DN"

, "User Filter"
: "User Filter"

, "User Search Scope"
: "User Search Scope"

, "Groups DN"
: "Groups DN"

, "Group Filter"
: "Lọc nhóm"

, "Group Search Scope"
: "Phạm vi tìm nhóm"

, "Use Rfc 2307 bis"
: "Sử dụng Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Độ dài người dùng ngắn nhất"

, "Max User Id"
: "Độ dài người dùng dài nhất"

, "Min Group Id"
: "Độ dài nhóm người dùng ngắn nhất"

, "Max Group Id"
: "Độ dài nhóm người dùng dài nhất"

, "Group UUID Attribute name"
: "Tên thuộc tính UUID nhóm"

, "User UUID Attribute name"
: "Tên thuộc tính UUID người dùng"

, "Readonly access"
: "Truy cập chỉ đọc"

, "Save config and install"
: "Lưu cấu hình và cài đặt"

, "Passwords don't match"
: "Mật khẩu không trùng nhau"

, "Should not be empty"
: "Không thể rỗng"

, "Setup"
: ""

, "Application, Applications"
: [
  "one: Ứng dụng\nother: Ứng dụng"

]
, "Name"
: "Tên"

, "Enabled"
: "Đã mở"

, "Order"
: "Sắp xếp"

, "Installed Version"
: "Phiên bản đã cài"

, "Available Version"
: "Phiên bản sẵn sàng"

, "Status"
: "Trạng thái"

, "Depends on"
: "Phụ thuộc vào"

, "Uninstall application"
: "Gỡ ứng dụng"

, "Update application"
: "Cập nhật ứng dụng"

, "Go to {0} login"
: "Tới đăng nhập {0}"

, "uninstall"
: "gỡ bỏ"

, "Do you really want to uninstall the application(s)?"
: "Bạn có muốn gỡ bỏ ứng dụng?"

, "This may take a while"
: "Có thể bạn phải đợi lâu"

, "Dependency Violation"
: "Xung đột các thành phần "

, "CLI Required"
: ""

, "Application"
: "one: Ứng dụng\nother: Ứng dụng"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Tôi đã đọc thỏa thuận về giấy phép sử dụng và chấp nhận nó."

, "License Agreement"
: "Thỏa thuận giấy phép sử dụng"

, "I have read the privacy agreement and accept it"
: "Tôi đã đọc chính sách riêng tư và chấp nhận nó"

, "Privacy Agreement"
: "Thỏa thuận chính sách"

, "Accept Terms and Conditions"
: "Điều khoản sử dụng"

, "Backend"
: "Nền tảng"

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Hostname"

, "Username"
: "Tên đăng nhập"

, "Password"
: "Mật khẩu"

, "Port"
: "Cổng"

, "Secure Connection"
: "Kết nối bảo mật"

, "None"
: "Không"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Sử dụng tài khoản hệ thống"

, "No"
: "Không"

, "Yes"
: "Có"

, "Append domain to login name"
: "Ghép domain vào tên đăng nhập"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin Password"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentication"

, "Login"
: "Đăng nhập"

, "Plain"
: "Thuần text"

, "Primary Domain"
: "Domain chính"

, "Secondary Domains (comma separated)"
: "Domain phụ (cách nhau bằng dấu phẩy)"

, "Notifications service address"
: "Địa chỉ thông báo dịch vụ"

, "Notification Username"
: "Người dùng thông báo"

, "Notification Password"
: "Mật khẩu thông báo"

, "Notifications local client (hostname or IP address)"
: "Notifications local client (hostname or IP address)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Database"

, "MySql User"
: "MySql User"

, "MySql Password"
: "MySql Password"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "User or UID"

, "Group or GID"
: "Group or GID"

, "Home Template"
: "Home Template"

, "Password Scheme"
: "Password Scheme"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Điều khỏa sử dụng"

, "Setup Checks"
: "Kiểm tra cài đặt"

, "Config Manager"
: "Quản lý cấu hình"

, "Authentication/Accounts"
: "Xác thực/ Tài khoản"

, "Email"
: "Email"

, "Application Manager"
: "Quản lý ứng dụng"

, "Setup"
: ""

, "Name"
: "Tên"

, "Enabled"
: "Đã mở"

, "Order"
: "Sắp xếp"

, "Installed Version"
: "Phiên bản đã cài"

, "Available Version"
: "Phiên bản sẵn sàng"

, "Status"
: "Trạng thái"

, "Depends on"
: "Phụ thuộc vào"

, "Install application"
: "Cài đặt ứng dụng"

, "Uninstall application"
: "Gỡ ứng dụng"

, "Update application"
: "Cập nhật ứng dụng"

, "Go to {0} login"
: "Tới đăng nhập {0}"

, "uninstall"
: "gỡ bỏ"

, "Do you really want to uninstall the application(s)?"
: "Bạn có muốn gỡ bỏ ứng dụng?"

, "This may take a while"
: "Có thể bạn phải đợi lâu"

, "Dependency Violation"
: "Xung đột các thành phần "

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Xóa mọi người dùng và nhóm người dùng"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Chuyển từ SQL sang LDAP sẽ xóa mọi người dùng, nhóm, và vai trò hiện tại. Bạn có thật sự muốn chuyển chế độ lưu trữ tài khoản sang LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Người Quản trị chính"

, "Initial admin login name"
: "Tên đăng nhập Quản trị chính"

, "Initial admin Password"
: "Mật khẩu Quản trị chính"

, "Password confirmation"
: "Xác nhận mật khẩu"

, "Authentication provider"
: "Nguồn xác thực"

, "Try to split username"
: "Thử tách tên đăng nhập"

, "Account canonical form"
: "Form đăng nhập duy nhất"

, "Account domain name"
: ""

, "Account domain short name"
: "Tên ngắn của domain"

, "Host"
: "Host"

, "Login name"
: "Tên đăng nhập"

, "Bind requires DN"
: "Bind requires DN"

, "Start TLS"
: ""

, "Base DN"
: "Base DN"

, "Search filter"
: "Bộ lọc tìm kiếm"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Lưu trữ tài khoản"

, "Default user group name"
: "Tên nhóm nguwowfi dùng mặc định"

, "Default admin group name"
: "Tên nhóm quản trị mặc định"

, "Login panel"
: "Màn hình đăng nhập"

, "Reuse last username logged"
: ""

, "Password Settings"
: "Thiết lập mật khẩu"

, "User can change password"
: "Người dùng có thể đổi mật khẩu"

, "Enable password policy"
: "Bật chính sách mật khẩu"

, "Only ASCII"
: "Chỉ ASCII"

, "Minimum length"
: "Độ dài tối thiểu"

, "Minimum word chars"
: "Ký tự chữ cái tối tiểu"

, "Minimum uppercase chars"
: "Ký tự in hoa tối thiểu"

, "Minimum special chars"
: "Ký tự đặc biệt tối thiểu"

, "Minimum numbers"
: "Số tối thiểu"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Cấm sử dụng 1 phần tên đăng nhập trong mật khẩu"

, "Redirect Settings"
: "Thiết lập chuyển hướng"

, "Redirect Url (redirect to login screen if empty)"
: "URL chuyển hướng (chuyển hướng tới màn hình đăng nhập rỗng)"

, "Redirect Always (if No, only redirect after logout)"
: "Luôn chuyển hướng (Nếu không, chỉ chuyển hướng sau khi thoát)"

, "Redirect to referring site, if exists"
: "Chuyển hướng tới trang trước đó, nếu có"

, "Password encoding"
: "Mã hóa mật khaaru"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "User DN"

, "User Filter"
: "User Filter"

, "User Search Scope"
: "User Search Scope"

, "Groups DN"
: "Groups DN"

, "Group Filter"
: "Lọc nhóm"

, "Group Search Scope"
: "Phạm vi tìm nhóm"

, "Use Rfc 2307 bis"
: "Sử dụng Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Độ dài người dùng ngắn nhất"

, "Max User Id"
: "Độ dài người dùng dài nhất"

, "Min Group Id"
: "Độ dài nhóm người dùng ngắn nhất"

, "Max Group Id"
: "Độ dài nhóm người dùng dài nhất"

, "Group UUID Attribute name"
: "Tên thuộc tính UUID nhóm"

, "User UUID Attribute name"
: "Tên thuộc tính UUID người dùng"

, "Readonly access"
: "Truy cập chỉ đọc"

, "Save config and install"
: "Lưu cấu hình và cài đặt"

, "Save config"
: "Lưu cấu hình"

, "Passwords don't match"
: "Mật khẩu không trùng nhau"

, "Should not be empty"
: "Không thể rỗng"

, "Performing Environment Checks..."
: "Đang thực hiện kiểm tra môi trường ..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Không có gì được tìm thấy {0}. Xin thay đổi điều kiện tìm kiếm của bạn, tùy chọn xem hoặc {1} bạn tìm kiếm trong đó."

, "Check"
: "Kiểm tra"

, "Result"
: "Kết quả"

, "Error"
: "Lỗi"

, "Run setup tests"
: "Chạy kiếm tra cài đặt"

, "Ignore setup tests"
: "Bỏ qua kiểm tra cài đặt"

, "Application, Applications"
: [
  "one: Ứng dụng\nother: Ứng dụng"

]
, "File"
: "File"

, "Setup Authentication"
: "Cài đặt xác thực"

, "Database"
: "Cơ sở dữ liệu"

, "User"
: "Người dùng"

, "Prefix"
: "Tiền tố"

, "Logging"
: "Ghi lỗi"

, "Filename"
: "Tên file"

, "Priority"
: "Độ quan trọng"

, "Caching"
: "Đệm"

, "Lifetime (seconds)"
: "Lifetime (seconds)"

, "Path"
: "Đường dẫn"

, "Queue"
: "Hàng đợi"

, "Session"
: "Session"

, "Temporary files"
: "Temporary files"

, "Temporary Files Path"
: "Temporary Files Path"

, "Filestore directory"
: "Filestore directory"

, "Filestore Path"
: "Filestore Path"

, "Addressbook Map panel"
: "Addressbook Map panel"

, "Map panel"
: "Map panel"

, "disabled"
: "tắt"

, "enabled"
: "mở"

, "Config file is not writable"
: "File cấu hình không thể lưu lại"

, "Download config file"
: "Download file cấu hình"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "one: Ứng dụng\nother: Ứng dụng"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
